@@ -25,7 +25,9 @@ fi
 if [ ! -d "${prefix}/dev" ]; then
     mkdir "${prefix}/dev"
 fi
-
+if [ ! -e "${prefix}/dev/fd" ]; then
+    ln -s /proc/self/fd "${prefix}/dev/fd"
+fi
 
 #
 #  Create the node
